summaryrefslogtreecommitdiffstats
path: root/kiosktool/kioskgui.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:00:45 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:00:45 -0600
commit867b7c23aa5ee22368683f23635ded9506587069 (patch)
tree8747f77cbce50d64c134ec5b6ba042c0652a3b2d /kiosktool/kioskgui.cpp
parentfa83271d8cc574c52a889303f76c8fa1988f0773 (diff)
downloadkiosktool-867b7c23aa5ee22368683f23635ded9506587069.tar.gz
kiosktool-867b7c23aa5ee22368683f23635ded9506587069.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kiosktool/kioskgui.cpp')
-rw-r--r--kiosktool/kioskgui.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kiosktool/kioskgui.cpp b/kiosktool/kioskgui.cpp
index ca615fe..ee9afac 100644
--- a/kiosktool/kioskgui.cpp
+++ b/kiosktool/kioskgui.cpp
@@ -59,7 +59,7 @@
#include "kiosksync.h"
KioskGui::KioskGui()
- : KMainWindow( 0, "kioskgui" ), m_profileSelectionPage(0),
+ : TDEMainWindow( 0, "kioskgui" ), m_profileSelectionPage(0),
m_componentSelectionPage(0), m_componentPage(0), m_profileAssignPage(0),
m_profilePropsPage(0), m_data(0),
m_activePage(0), m_profile(0), m_componentData(0)
@@ -72,7 +72,7 @@ KioskGui::KioskGui()
updateBackground();
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(m_view);
setWidgetBackground(m_view);
@@ -167,8 +167,8 @@ void KioskGui::setupActions()
// KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
// KStdAction::configureToolbars(this, TQT_SLOT(optionsConfigureToolbars()), actionCollection());
KStdAction::preferences(this, TQT_SLOT(slotConfig()), actionCollection());
- m_uploadAction = new KAction(i18n("Upload &All Profiles"), TQString(), 0, this, TQT_SLOT(uploadAllProfiles()), actionCollection(), "upload_all");
- m_backgroundAction = new KToggleAction(i18n("Background Graphics"), TQString(), 0, this, TQT_SLOT(slotUpdateBackground()), actionCollection(), "show_background");
+ m_uploadAction = new TDEAction(i18n("Upload &All Profiles"), TQString(), 0, this, TQT_SLOT(uploadAllProfiles()), actionCollection(), "upload_all");
+ m_backgroundAction = new TDEToggleAction(i18n("Background Graphics"), TQString(), 0, this, TQT_SLOT(slotUpdateBackground()), actionCollection(), "show_background");
updateActions();
}
@@ -72,7 +72,7 @@ KioskGui::KioskGui()
updateBackground();
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(m_view);
setWidgetBackground(m_view);